/**
 * GitDocumentDB plugin for remote connection using NodeGit
 * Copyright (c) Hidekazu Kubota
 *
 * This source code is licensed under the Mozilla Public License Version 2.0
 * found in the LICENSE file in the root directory of this source tree.
 */
/**
 * Namespace for errors
 *
 * @public
 */
export declare namespace Err {
    /**
     * BaseError
     *
     * @privateRemarks
     * Use 'unknown' type assertion for constructor arguments in subclass of BaseError
     * to use 'expect' in test. See https://github.com/facebook/jest/issues/8279
     */
    class BaseError extends Error {
        constructor(e: string);
    }
    /**
     * @public
     */
    export class CannotConnectError extends BaseError {
        retry: number;
        constructor(retry: number, url: string, mes: string);
    }
    /**
    * @public
    */
    export class HttpProtocolRequiredError extends BaseError {
        constructor(url: unknown);
    }
    /**
     * @public
     */
    export class InvalidRepositoryURLError extends BaseError {
        constructor(url: unknown);
    }
    /**
     * @public
     */
    export class UndefinedPersonalAccessTokenError extends BaseError {
        constructor();
    }
    /**
     * @public
     */
    export class InvalidSSHKeyPathError extends BaseError {
        constructor();
    }
    /**
     * @public
     */
    export class RequestTimeoutError extends BaseError {
        constructor(url: unknown);
    }
    /**
     * @public
     */
    export class SocketTimeoutError extends BaseError {
        constructor(url: unknown);
    }
    /**
     * @public
     */
    export class HTTPNetworkError extends BaseError {
        constructor(mes: unknown);
    }
    export {};
}
//# sourceMappingURL=error.d.ts.map