"use strict";
/**
 * GitDocumentDB plugin for remote connection using NodeGit
 * Copyright (c) Hidekazu Kubota
 *
 * This source code is licensed under the Mozilla Public License Version 2.0
 * found in the LICENSE file in the root directory of this source tree.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Err = void 0;
/**
 * Namespace for errors
 *
 * @public
 */
var Err;
(function (Err) {
    /**
     * BaseError
     *
     * @privateRemarks
     * Use 'unknown' type assertion for constructor arguments in subclass of BaseError
     * to use 'expect' in test. See https://github.com/facebook/jest/issues/8279
     */
    class BaseError extends Error {
        constructor(e) {
            super(e);
            this.name = new.target.name;
            Object.setPrototypeOf(this, new.target.prototype);
        }
    }
    /**
     * @public
     */
    class CannotConnectError extends BaseError {
        constructor(retry, url, mes) {
            super(`Cannot connect to ${url}: ${mes}`);
            this.retry = retry;
        }
    }
    Err.CannotConnectError = CannotConnectError;
    /**
    * @public
    */
    class HttpProtocolRequiredError extends BaseError {
        constructor(url) {
            super(`HTTP protocol is required: ${url}`);
        }
    }
    Err.HttpProtocolRequiredError = HttpProtocolRequiredError;
    /**
     * @public
     */
    class InvalidRepositoryURLError extends BaseError {
        constructor(url) {
            super(`Repository URL is invalid: ${url}`);
        }
    }
    Err.InvalidRepositoryURLError = InvalidRepositoryURLError;
    /**
     * @public
     */
    class UndefinedPersonalAccessTokenError extends BaseError {
        constructor() {
            super(`Personal Access Token of your GitHub account is needed.`);
        }
    }
    Err.UndefinedPersonalAccessTokenError = UndefinedPersonalAccessTokenError;
    /**
     * @public
     */
    class InvalidSSHKeyPathError extends BaseError {
        constructor() {
            const e = `Invalid SSH key path`;
            super(e);
        }
    }
    Err.InvalidSSHKeyPathError = InvalidSSHKeyPathError;
    /**
     * @public
     */
    class RequestTimeoutError extends BaseError {
        constructor(url) {
            super(`Request timeout: ${url}`);
        }
    }
    Err.RequestTimeoutError = RequestTimeoutError;
    /**
     * @public
     */
    class SocketTimeoutError extends BaseError {
        constructor(url) {
            super(`Socket timeout: ${url}`);
        }
    }
    Err.SocketTimeoutError = SocketTimeoutError;
    /**
     * @public
     */
    class HTTPNetworkError extends BaseError {
        constructor(mes) {
            super(`HTTPNetworkError: ${mes}`);
        }
    }
    Err.HTTPNetworkError = HTTPNetworkError;
})(Err = exports.Err || (exports.Err = {}));
//# sourceMappingURL=error.js.map